==> koshoten.net-2.1.2.tar.gz: koshoten-net/catalog/includes/modules/product_listing.php <==
<?php
/*
  $Id: product_listing.php,v 1.1.1.1 2005/06/30 05:04:19 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/
?>
<div id="productsList">
<?php
  $listing_numrows_sql = $listing_sql;
  $listing_split = new splitPageResults($HTTP_GET_VARS['page'], MAX_DISPLAY_SEARCH_RESULTS, $listing_sql, $listing_numrows);
// fix counted products
  $listing_numrows = tep_db_query($listing_numrows_sql);
  $listing_numrows = tep_db_num_rows($listing_numrows);

  if ( ($listing_numrows > 0) && ( (PREV_NEXT_BAR_LOCATION == '1') || (PREV_NEXT_BAR_LOCATION == '3') ) ) {
?>
  <table class="listHeader">
    <tr>
      <td class="listCount"><?php echo $listing_split->display_count($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, $HTTP_GET_VARS['page'], TEXT_DISPLAY_NUMBER_OF_PRODUCTS); ?></td>
      <td class="listPrevNext"><?php echo TEXT_RESULT_PAGE; ?> <?php echo $listing_split->display_links($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, MAX_DISPLAY_PAGE_LINKS, $HTTP_GET_VARS['page'], tep_get_all_get_params(array('page', 'info', 'x', 'y'))); ?></td>
    </tr>
  </table>
<?php
  }
?>
<?php
  $list_box_contents = array();
  $cur_row = 0;

  for ($col=0, $n=sizeof($column_list); $col<$n; $col++) {
    switch ($column_list[$col]) {
      case 'PRODUCT_LIST_MODEL':
        $lc_text = TABLE_HEADING_MODEL;
        $lc_param = 'productListModel';
        break;
      case 'PRODUCT_LIST_NAME':
        $lc_text = TABLE_HEADING_PRODUCTS;
        $lc_param = 'productListName';
        break;
      case 'PRODUCT_LIST_SUBTITLE':
        $lc_text = TABLE_HEADING_SUBTITLE;
        $lc_param = 'productListSubtitle';
        break;
      case 'PRODUCT_LIST_SERIES_TITLE':
        $lc_text = TABLE_HEADING_SERIES_TITLE;
        $lc_param = 'productListSeriesTitle';
        break;
      case 'PRODUCT_LIST_AUTHOR':
        $lc_text = TABLE_HEADING_AUTHOR;
        $lc_param = 'productListAuthor';
        break;
      case 'PRODUCT_LIST_PUBLISHED':
        $lc_text = TABLE_HEADING_PUBLISHED;
        $lc_param = 'productListPublished';
        break;
      case 'PRODUCT_LIST_VOLUME':
        $lc_text = TABLE_HEADING_VOLUME;
        $lc_param = 'productListVolume';
        break;
      case 'PRODUCT_LIST_ISBN':
        $lc_text = TABLE_HEADING_ISBN;
        $lc_param = 'productListIsbn';
        break;
      case 'PRODUCT_LIST_DESCRIPTION':
        $lc_text = TABLE_HEADING_DESCRIPTION;
        $lc_param = 'productListDescription';
        break;
      case 'PRODUCT_LIST_PUBLISHERS':
        $lc_text = TABLE_HEADING_PUBLISHERS;
        $lc_param = 'productListPublishers';
        break;
      case 'PRODUCT_LIST_PRICE':
        $lc_text = TABLE_HEADING_PRICE;
        $lc_param = 'productListPrice';
        break;
      case 'PRODUCT_LIST_QUANTITY':
        $lc_text = TABLE_HEADING_QUANTITY;
        $lc_param = 'productListQuantity';
        break;
      case 'PRODUCT_LIST_WEIGHT':
        $lc_text = TABLE_HEADING_WEIGHT;
        $lc_param = 'productListWeight';
        break;
      case 'PRODUCT_LIST_IMAGE':
        $lc_text = TABLE_HEADING_IMAGE;
        $lc_param = 'productListImage';
        break;
      case 'PRODUCT_LIST_BUY_NOW':
        $lc_text = TABLE_HEADING_BUY_NOW;
        $lc_param = 'productListBuyNow';
        break;
    }
    
    if ( ($column_list[$col] != 'PRODUCT_LIST_BUY_NOW') && ($column_list[$col] != 'PRODUCT_LIST_IMAGE') && ($column_list[$col] != 'PRODUCT_LIST_DESCRIPTION') ) {
      $lc_text = tep_create_sort_heading($HTTP_GET_VARS['sort'], $col+1, $lc_text);
    }
    
    if ($lc_text == '') {
      $lc_text = '&nbsp;';
    }

    $list_box_contents[$cur_row][] = array('params' => 'class="' . $lc_param . '"',
                                           'text' => $lc_text);
  }

  if ($listing_numrows > 0) {
    $number_of_products = '0';
    $listing_query = tep_db_query($listing_sql);
    while ($listing = tep_db_fetch_array($listing_query)) {
      $number_of_products++;

      if (($number_of_products/2) == floor($number_of_products/2)) {
        $list_box_contents[] = array('params' => 'class="even"');
      } else {
        $list_box_contents[] = array('params' => 'class="odd"');
      }

      $cur_row = sizeof($list_box_contents) - 1;

      for ($col=0, $n=sizeof($column_list); $col<$n; $col++) {
        $lc_param = '';

        switch ($column_list[$col]) {
          case 'PRODUCT_LIST_MODEL':
            $lc_param = 'productListModel';
            $lc_text = $listing['products_model'];
            break;
          case 'PRODUCT_LIST_NAME':
            $lc_param = 'productListName';
            if (isset($HTTP_GET_VARS['manufacturers_id'])) {
              $lc_text = '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'manufacturers_id=' . $HTTP_GET_VARS['manufacturers_id'] . '&products_id=' . $listing['products_id']) . '">' . $listing['products_name'] . '</a>';
            } else {
              $lc_text = '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, ($cPath ? 'cPath=' . $cPath . '&' : '') . 'products_id=' . $listing['products_id']) . '">' . $listing['products_name'] . '</a>';
            }
            break;
          case 'PRODUCT_LIST_SUBTITLE':
            $lc_param = 'productListSubtitle';
            $lc_text = $listing['products_subtitle'];
            break;
          case 'PRODUCT_LIST_SERIES_TITLE':
            $lc_param = 'productListSeriesTitle';
            $lc_text = $listing['products_series_title'];
            break;
          case 'PRODUCT_LIST_AUTHOR':
            $lc_param = 'productListAuthor';
            $lc_text = $listing['products_author'];
            break;
          case 'PRODUCT_LIST_PUBLISHED':
            $lc_param = 'productListPublished';
            $lc_text = $listing['products_published'];
            break;
          case 'PRODUCT_LIST_VOLUME':
            $lc_param = 'productListVolume';
            $lc_text = $listing['products_volume'];
            break;
          case 'PRODUCT_LIST_ISBN':
            $lc_param = 'productListIsbn';
            $lc_text = $listing['products_isbn'];
            break;
          case 'PRODUCT_LIST_PUBLISHERS':
            $lc_param = 'productListPublishers';
            $lc_text = $listing['products_publishers'];
            break;
          case 'PRODUCT_LIST_DESCRIPTION':
            $lc_param = 'productListDescription';
            if (KN_CFG_PRODUCT_LIST_WITHIN_DESCRIPTION == 'true') {
              $lc_text = '';
              if ((KN_CFG_USE_SUBTITLE == 'true') && ($listing['products_subtitle'])) {
                $lc_text .= $listing['products_subtitle'] . ' ';
              }
              if ((KN_CFG_USE_SERIES_TITLE == 'true') && ($listing['products_series_title'])) {
                $lc_text .= $listing['products_series_title'] . ' ';
              }
              $lc_text .= $listing['products_description'] . ' ';
              if ((KN_CFG_USE_VOLUME == 'true') && ($listing['products_volume'])) {
                $lc_text .= $listing['products_volume'] . ' ';
              }
              if ((KN_CFG_USE_PUBLISHED == 'true') && ($listing['products_published'])) {
                $lc_text .= $listing['products_published'] . ' ';
              }
              if ((KN_CFG_USE_PUBLISHERS == 'true') && ($listing['products_publishers'])) {
                $lc_text .= $listing['products_publishers'];
              }
            } else {
              $lc_text = $listing['products_description'];
            }
            break;
          case 'PRODUCT_LIST_PRICE':
            $lc_param = 'productListPrice';
            if (tep_not_null($listing['specials_new_products_price'])) {
              $lc_text = '<s>' .  $currencies->display_price($listing['products_price'], tep_get_tax_rate($listing['products_tax_class_id'])) . '</s>&nbsp;&nbsp;<span class="productSpecialPrice">' . $currencies->display_price($listing['specials_new_products_price'], tep_get_tax_rate($listing['products_tax_class_id'])) . '</span>';
            } else {
              $lc_text = $currencies->display_price($listing['products_price'], tep_get_tax_rate($listing['products_tax_class_id']));
            }
            break;
          case 'PRODUCT_LIST_QUANTITY':
            $lc_param = 'productListQuantity';
            $lc_text = $listing['products_quantity'];
            break;
          case 'PRODUCT_LIST_WEIGHT':
            $lc_param = 'productListWeight';
            $lc_text = $listing['products_weight'];
            break;
          case 'PRODUCT_LIST_IMAGE':
            $lc_param = 'productListImage';
            if (isset($HTTP_GET_VARS['manufacturers_id'])) {
              $lc_text = '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'manufacturers_id=' . $HTTP_GET_VARS['manufacturers_id'] . '&products_id=' . $listing['products_id']) . '">' . tep_image(DIR_WS_IMAGES . $listing['products_image'], $listing['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . '</a>';
            } else {
              $lc_text = '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, ($cPath ? 'cPath=' . $cPath . '&' : '') . 'products_id=' . $listing['products_id']) . '">' . tep_image(DIR_WS_IMAGES . $listing['products_image'], $listing['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . '</a>';
            }
            break;
          case 'PRODUCT_LIST_BUY_NOW':
            $lc_param = 'productListBuyNow';
            $lc_text = '<a href="' . tep_href_link(basename($PHP_SELF), tep_get_all_get_params(array('action')) . 'action=buy_now&products_id=' . $listing['products_id']) . '">' . tep_image_button('button_buy_now.gif', TEXT_BUY . $listing['products_name'] . TEXT_NOW) . '</a>';
            break;
        }

    if ($lc_text == '') {
      $lc_text = '&nbsp;';
    }

        $list_box_contents[$cur_row][] = array('params' => 'class="' . $lc_param . '"',
                                               'text'  => $lc_text);
      }
    }

    new listingBox($list_box_contents, true, true);
  } else {
?>
  <div class="noData"><?php echo (isset($HTTP_GET_VARS['manufacturers_id']) ? TEXT_NO_PRODUCTS2 : TEXT_NO_PRODUCTS); ?></div>
<?php
  }

  if ( ($listing_numrows > 0) && ((PREV_NEXT_BAR_LOCATION == '2') || (PREV_NEXT_BAR_LOCATION == '3')) ) {
?>
  <table class="listFooter">
    <tr>
      <td class="listCount"><?php echo $listing_split->display_count($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, $HTTP_GET_VARS['page'], TEXT_DISPLAY_NUMBER_OF_PRODUCTS); ?></td>
      <td class="listPrevNext"><?php echo TEXT_RESULT_PAGE; ?> <?php echo $listing_split->display_links($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, MAX_DISPLAY_PAGE_LINKS, $HTTP_GET_VARS['page'], tep_get_all_get_params(array('page', 'info', 'x', 'y'))); ?></td>
    </tr>
  </table>
<?php
  }
?>
</div>

==> koshoten.net-2.1.3.tar.gz: koshoten-net/catalog/includes/modules/product_listing.php <==
<?php
/*
  $Id: product_listing.php,v 1.2 2005/09/24 03:06:41 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/
?>
<div id="productsList">
<?php
  $listing_numrows_sql = $listing_sql;
  $listing_split = new splitPageResults($HTTP_GET_VARS['page'], MAX_DISPLAY_SEARCH_RESULTS, $listing_sql, $listing_numrows);
// fix counted products
  $listing_numrows = tep_db_query($listing_numrows_sql);
  $listing_numrows = tep_db_num_rows($listing_numrows);

  if ( ($listing_numrows > 0) && ( (PREV_NEXT_BAR_LOCATION == '1') || (PREV_NEXT_BAR_LOCATION == '3') ) ) {
?>
  <table class="listHeader">
    <tr>
      <td class="listCount"><?php echo $listing_split->display_count($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, $HTTP_GET_VARS['page'], TEXT_DISPLAY_NUMBER_OF_PRODUCTS); ?></td>
      <td class="listPrevNext"><?php echo TEXT_RESULT_PAGE; ?> <?php echo $listing_split->display_links($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, MAX_DISPLAY_PAGE_LINKS, $HTTP_GET_VARS['page'], tep_get_all_get_params(array('page', 'info', 'x', 'y'))); ?></td>
    </tr>
  </table>
<?php
  }
?>
<?php
  $list_box_contents = array();
  $cur_row = 0;

  for ($col=0, $n=sizeof($column_list); $col<$n; $col++) {
    switch ($column_list[$col]) {
      case 'PRODUCT_LIST_MODEL':
        $lc_text = TABLE_HEADING_MODEL;
        $lc_param = 'productListModel';
        break;
      case 'PRODUCT_LIST_NAME':
        $lc_text = TABLE_HEADING_PRODUCTS;
        $lc_param = 'productListName';
        break;
      case 'PRODUCT_LIST_SUBTITLE':
        $lc_text = TABLE_HEADING_SUBTITLE;
        $lc_param = 'productListSubtitle';
        break;
      case 'PRODUCT_LIST_SERIES_TITLE':
        $lc_text = TABLE_HEADING_SERIES_TITLE;
        $lc_param = 'productListSeriesTitle';
        break;
      case 'PRODUCT_LIST_AUTHOR':
        $lc_text = TABLE_HEADING_AUTHOR;
        $lc_param = 'productListAuthor';
        break;
      case 'PRODUCT_LIST_PUBLISHED':
        $lc_text = TABLE_HEADING_PUBLISHED;
        $lc_param = 'productListPublished';
        break;
      case 'PRODUCT_LIST_VOLUME':
        $lc_text = TABLE_HEADING_VOLUME;
        $lc_param = 'productListVolume';
        break;
      case 'PRODUCT_LIST_ISBN':
        $lc_text = TABLE_HEADING_ISBN;
        $lc_param = 'productListIsbn';
        break;
      case 'PRODUCT_LIST_DESCRIPTION':
        $lc_text = TABLE_HEADING_DESCRIPTION;
        $lc_param = 'productListDescription';
        break;
      case 'PRODUCT_LIST_PUBLISHERS':
        $lc_text = TABLE_HEADING_PUBLISHERS;
        $lc_param = 'productListPublishers';
        break;
      case 'PRODUCT_LIST_PRICE':
        $lc_text = TABLE_HEADING_PRICE;
        $lc_param = 'productListPrice';
        break;
      case 'PRODUCT_LIST_QUANTITY':
        $lc_text = TABLE_HEADING_QUANTITY;
        $lc_param = 'productListQuantity';
        break;
      case 'PRODUCT_LIST_WEIGHT':
        $lc_text = TABLE_HEADING_WEIGHT;
        $lc_param = 'productListWeight';
        break;
      case 'PRODUCT_LIST_IMAGE':
        $lc_text = TABLE_HEADING_IMAGE;
        $lc_param = 'productListImage';
        break;
      case 'PRODUCT_LIST_BUY_NOW':
        $lc_text = TABLE_HEADING_BUY_NOW;
        $lc_param = 'productListBuyNow';
        break;
    }
    
    if ( ($column_list[$col] != 'PRODUCT_LIST_BUY_NOW') && ($column_list[$col] != 'PRODUCT_LIST_IMAGE') && ($column_list[$col] != 'PRODUCT_LIST_DESCRIPTION') ) {
      $lc_text = tep_create_sort_heading($HTTP_GET_VARS['sort'], $col+1, $lc_text);
    }
    
    if ($lc_text == '') {
      $lc_text = '&nbsp;';
    }

    $list_box_contents[$cur_row][] = array('params' => 'class="' . $lc_param . '"',
                                           'text' => $lc_text);
  }

  if ($listing_numrows > 0) {
    $number_of_products = '0';
    $listing_query = tep_db_query($listing_sql);
    while ($listing = tep_db_fetch_array($listing_query)) {
      $number_of_products++;

      if (($number_of_products/2) == floor($number_of_products/2)) {
        $list_box_contents[] = array('params' => 'class="even"');
      } else {
        $list_box_contents[] = array('params' => 'class="odd"');
      }

      $cur_row = sizeof($list_box_contents) - 1;

      for ($col=0, $n=sizeof($column_list); $col<$n; $col++) {
        $lc_param = '';

        switch ($column_list[$col]) {
          case 'PRODUCT_LIST_MODEL':
            $lc_param = 'productListModel';
            $lc_text = $listing['products_model'];
            break;
          case 'PRODUCT_LIST_NAME':
            $lc_param = 'productListName';
            if (!empty($HTTP_GET_VARS['manufacturers_id'])) {
              $lc_text = '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'manufacturers_id=' . $HTTP_GET_VARS['manufacturers_id'] . '&products_id=' . $listing['products_id']) . '">' . $listing['products_name'] . '</a>';
            } else {
              $lc_text = '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, ($cPath ? 'cPath=' . $cPath . '&' : '') . 'products_id=' . $listing['products_id']) . '">' . $listing['products_name'] . '</a>';
            }
            break;
          case 'PRODUCT_LIST_SUBTITLE':
            $lc_param = 'productListSubtitle';
            $lc_text = $listing['products_subtitle'];
            break;
          case 'PRODUCT_LIST_SERIES_TITLE':
            $lc_param = 'productListSeriesTitle';
            $lc_text = $listing['products_series_title'];
            break;
          case 'PRODUCT_LIST_AUTHOR':
            $lc_param = 'productListAuthor';
            $lc_text = $listing['products_author'];
            break;
          case 'PRODUCT_LIST_PUBLISHED':
            $lc_param = 'productListPublished';
            $lc_text = $listing['products_published'];
            break;
          case 'PRODUCT_LIST_VOLUME':
            $lc_param = 'productListVolume';
            $lc_text = $listing['products_volume'];
            break;
          case 'PRODUCT_LIST_ISBN':
            $lc_param = 'productListIsbn';
            $lc_text = $listing['products_isbn'];
            break;
          case 'PRODUCT_LIST_PUBLISHERS':
            $lc_param = 'productListPublishers';
            $lc_text = $listing['products_publishers'];
            break;
          case 'PRODUCT_LIST_DESCRIPTION':
            $lc_param = 'productListDescription';
            if (KN_CFG_PRODUCT_LIST_WITHIN_DESCRIPTION == 'true') {
              $lc_text = '';
              if ((KN_CFG_USE_SUBTITLE == 'true') && ($listing['products_subtitle'])) {
                $lc_text .= $listing['products_subtitle'] . ' ';
              }
              if ((KN_CFG_USE_SERIES_TITLE == 'true') && ($listing['products_series_title'])) {
                $lc_text .= $listing['products_series_title'] . ' ';
              }
              $lc_text .= $listing['products_description'] . ' ';
              if ((KN_CFG_USE_VOLUME == 'true') && ($listing['products_volume'])) {
                $lc_text .= $listing['products_volume'] . ' ';
              }
              if ((KN_CFG_USE_PUBLISHED == 'true') && ($listing['products_published'])) {
                $lc_text .= $listing['products_published'] . ' ';
              }
              if ((KN_CFG_USE_PUBLISHERS == 'true') && ($listing['products_publishers'])) {
                $lc_text .= $listing['products_publishers'];
              }
            } else {
              $lc_text = $listing['products_description'];
            }
            break;
          case 'PRODUCT_LIST_PRICE':
            $lc_param = 'productListPrice';
            if (tep_not_null($listing['specials_new_products_price'])) {
              $lc_text = '<s>' .  $currencies->display_price($listing['products_price'], tep_get_tax_rate($listing['products_tax_class_id'])) . '</s>&nbsp;&nbsp;<span class="productSpecialPrice">' . $currencies->display_price($listing['specials_new_products_price'], tep_get_tax_rate($listing['products_tax_class_id'])) . '</span>';
            } else {
              $lc_text = $currencies->display_price($listing['products_price'], tep_get_tax_rate($listing['products_tax_class_id']));
            }
            break;
          case 'PRODUCT_LIST_QUANTITY':
            $lc_param = 'productListQuantity';
            $lc_text = $listing['products_quantity'];
            break;
          case 'PRODUCT_LIST_WEIGHT':
            $lc_param = 'productListWeight';
            $lc_text = $listing['products_weight'];
            break;
          case 'PRODUCT_LIST_IMAGE':
            $lc_param = 'productListImage';
            if (!empty($HTTP_GET_VARS['manufacturers_id'])) {
              $lc_text = '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'manufacturers_id=' . $HTTP_GET_VARS['manufacturers_id'] . '&products_id=' . $listing['products_id']) . '">' . tep_image(DIR_WS_IMAGES . $listing['products_image'], $listing['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . '</a>';
            } else {
              $lc_text = '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, ($cPath ? 'cPath=' . $cPath . '&' : '') . 'products_id=' . $listing['products_id']) . '">' . tep_image(DIR_WS_IMAGES . $listing['products_image'], $listing['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT) . '</a>';
            }
            break;
          case 'PRODUCT_LIST_BUY_NOW':
            $lc_param = 'productListBuyNow';
            $lc_text = '<a href="' . tep_href_link(basename($PHP_SELF), tep_get_all_get_params(array('action')) . 'action=buy_now&products_id=' . $listing['products_id']) . '">' . tep_image_button('button_buy_now.gif', TEXT_BUY . $listing['products_name'] . TEXT_NOW) . '</a>';
            break;
        }

    if ($lc_text == '') {
      $lc_text = '&nbsp;';
    }

        $list_box_contents[$cur_row][] = array('params' => 'class="' . $lc_param . '"',
                                               'text'  => $lc_text);
      }
    }

    new listingBox($list_box_contents, true, true);
  } else {
?>
  <div class="noData"><?php echo (!empty($HTTP_GET_VARS['manufacturers_id']) ? TEXT_NO_PRODUCTS2 : TEXT_NO_PRODUCTS); ?></div>
<?php
  }

  if ( ($listing_numrows > 0) && ((PREV_NEXT_BAR_LOCATION == '2') || (PREV_NEXT_BAR_LOCATION == '3')) ) {
?>
  <table class="listFooter">
    <tr>
      <td class="listCount"><?php echo $listing_split->display_count($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, $HTTP_GET_VARS['page'], TEXT_DISPLAY_NUMBER_OF_PRODUCTS); ?></td>
      <td class="listPrevNext"><?php echo TEXT_RESULT_PAGE; ?> <?php echo $listing_split->display_links($listing_numrows, MAX_DISPLAY_SEARCH_RESULTS, MAX_DISPLAY_PAGE_LINKS, $HTTP_GET_VARS['page'], tep_get_all_get_params(array('page', 'info', 'x', 'y'))); ?></td>
    </tr>
  </table>
<?php
  }
?>
</div>
